@@ -13,9 +13,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-print-utils.h 6588 2006-09-13 11:34:25Z chpe $
+ *  $Id: ephy-print-utils.h 7143 2007-07-10 18:45:59Z chpe $
  */
 
 #ifndef EPHY_PRINT_UTILS_H
@@ -27,20 +27,6 @@
 
 G_BEGIN_DECLS
 
-GtkPrintSettings *ephy_print_utils_settings_new_from_file	(const gchar       *file_name,
-							 	 GError           **error);
-
-GtkPrintSettings *ephy_print_utils_settings_new_from_key_file	(GKeyFile          *key_file,
-								 GError           **error);
-
-gboolean	  ephy_print_utils_settings_to_file		(GtkPrintSettings  *settings,
-								 const char        *file_name,
-								 GError           **error);
-
-gboolean	  ephy_print_utils_settings_to_key_file		(GtkPrintSettings  *settings,
-								 GKeyFile          *key_file,
-								 GError           **error);
-
 GtkPageSetup	 *ephy_print_utils_page_setup_new_from_file	(const gchar       *file_name,
 							 	 GError           **error);
 
