@@ -1,7 +1,7 @@
 /*
  *  Copyright © 2002 Jorn Baayen
  *  Copyright © 2003, 2004 Marco Pesenti Gritti
- *  Copyright © 2004 Christian Persch
+ *  Copyright © 2004, 2007 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,9 +15,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-statusbar.c 6772 2006-12-30 22:15:15Z chpe $
+ *  $Id: ephy-statusbar.c 7127 2007-07-10 11:56:30Z chpe $
  */
 
 #include "config.h"
@@ -34,11 +34,9 @@
 #include <gtk/gtkimage.h>
 #include <gtk/gtkwidget.h>
 #include <gtk/gtkvseparator.h>
-#include <gtk/gtkversion.h>
 
 static void ephy_statusbar_class_init	(EphyStatusbarClass *klass);
 static void ephy_statusbar_init		(EphyStatusbar *t);
-static void ephy_statusbar_finalize	(GObject *object);
 
 #define EPHY_STATUSBAR_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_STATUSBAR, EphyStatusbarPrivate))
 
@@ -92,42 +90,13 @@ ephy_statusbar_get_type (void)
 	return type;
 }
 
-#if !GTK_CHECK_VERSION (2, 11, 0)
-static void
-ephy_statusbar_size_allocate (GtkWidget *widget,
-			      GtkAllocation *allocation)
-{
-	GtkStatusbar *gstatusbar = GTK_STATUSBAR (widget);
-	EphyStatusbar *statusbar = EPHY_STATUSBAR (widget);
-	EphyStatusbarPrivate *priv = statusbar->priv;
-	GtkWidget *label;
-
-	/* HACK HACK HACK ! */
-	label = gstatusbar->label;
-	gstatusbar->label = priv->hbox;
-
-	GTK_WIDGET_CLASS (parent_class)->size_allocate (widget, allocation);
-
-	gstatusbar->label = label;
-}
-#endif /* GTK 2.11.0 */
-
 static void
 ephy_statusbar_class_init (EphyStatusbarClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
-#if !GTK_CHECK_VERSION (2, 11, 0)
-	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
-#endif
 
 	parent_class = g_type_class_peek_parent (klass);
 
-	object_class->finalize = ephy_statusbar_finalize;
-
-#if !GTK_CHECK_VERSION (2, 11, 0)
-	widget_class->size_allocate = ephy_statusbar_size_allocate;
-#endif
-
 	signals[LOCK_CLICKED] =
 		g_signal_new
 			("lock-clicked",
@@ -146,25 +115,16 @@ static void
 create_caret_indicator (EphyStatusbar *statusbar)
 {
 	EphyStatusbarPrivate *priv = statusbar->priv;
-	GtkWidget *label, *ebox;
+	GtkWidget *label;
 
-	priv->caret_indicator = ebox = gtk_event_box_new ();
-	gtk_event_box_set_visible_window (GTK_EVENT_BOX (ebox), FALSE);
-	gtk_widget_show (ebox);
-
-	/* Translators: this is displayed in the statusbar; choose a short word
-	 * or even an abbreviation.
-	 */
-	label = gtk_label_new (_("Caret"));
-	gtk_container_add (GTK_CONTAINER (ebox), label);
+	priv->caret_indicator = label = gtk_label_new (_("Caret"));
 	gtk_widget_show (label);
 
-	gtk_tooltips_set_tip (statusbar->tooltips, ebox,
-			      /* Translators: this is the tooltip on the "Caret" icon
-			       * in the statusbar.
-			       */
-			      _("In keyboard selection mode, press F7 to exit"),
-			      NULL);
+	gtk_widget_set_tooltip_text (label,
+				     /* Translators: this is the tooltip on the "Caret" icon
+				      * in the statusbar.
+				      */
+				     _("In keyboard selection mode, press F7 to exit"));
 
 	ephy_statusbar_add_widget (statusbar, priv->caret_indicator);
 }
@@ -220,15 +180,21 @@ create_statusbar_progress (EphyStatusbar *s)
 	EphyStatusbarPrivate *priv = s->priv;
 	GtkWidget *vbox;
 
-	vbox = gtk_vbox_new (TRUE, 0);
-	gtk_box_pack_end (GTK_BOX (priv->hbox), vbox, FALSE, TRUE, 0);
+	vbox = gtk_vbox_new (FALSE, 0);
+	gtk_box_pack_end (GTK_BOX (priv->hbox), vbox, FALSE, FALSE, 0);
 
-	s->priv->progressbar = gtk_progress_bar_new ();
-	gtk_box_pack_start(GTK_BOX (vbox),
-			  GTK_WIDGET (s->priv->progressbar),
-		 	  FALSE, FALSE, 0);
+	priv->progressbar = gtk_progress_bar_new ();
+	gtk_box_pack_start (GTK_BOX (vbox),
+			    GTK_WIDGET (priv->progressbar),
+		 	    TRUE, TRUE, 1);
+
+        /* We need to set the vertical size request to a small value here,
+         * because the progressbar's default size request is taller than the whole
+         * statusbar. Packing it with expand&fill in the vbox above will nevertheless
+         * make it use the greatest available height.
+         */
+	gtk_widget_set_size_request (priv->progressbar, -1, 10);
 
-	gtk_widget_set_size_request (s->priv->progressbar, -1, 10);
 	gtk_widget_show_all (vbox);
 }
 
@@ -242,9 +208,6 @@ ephy_statusbar_init (EphyStatusbar *t)
 
 	gtk_statusbar_set_has_resize_grip (gstatusbar, TRUE);
 
-	t->tooltips = gtk_tooltips_new ();
-	g_object_ref_sink (t->tooltips);
-
 	priv->hbox = gtk_hbox_new (FALSE, 4);
 
 	priv->icon_container = gtk_hbox_new (FALSE, 4);
@@ -280,16 +243,6 @@ ephy_statusbar_init (EphyStatusbar *t)
 	create_statusbar_progress (t);
 }
 
-static void
-ephy_statusbar_finalize (GObject *object)
-{
-	EphyStatusbar *t = EPHY_STATUSBAR (object);
-
-	g_object_unref (t->tooltips);
-
-	G_OBJECT_CLASS (parent_class)->finalize (object);
-}
-
 /**
  * ephy_statusbar_new:
  * 
@@ -334,11 +287,12 @@ ephy_statusbar_set_security_state (EphyStatusbar *statusbar,
 				   const char *stock_id,
 				   const char *tooltip)
 {
-	gtk_image_set_from_stock (GTK_IMAGE (statusbar->priv->security_icon),
+	EphyStatusbarPrivate *priv = statusbar->priv;
+
+	gtk_image_set_from_stock (GTK_IMAGE (priv->security_icon),
 				  stock_id, GTK_ICON_SIZE_MENU);
 
-	gtk_tooltips_set_tip (statusbar->tooltips, statusbar->priv->security_evbox,
-			      tooltip, NULL);
+	gtk_widget_set_tooltip_text (priv->security_icon, tooltip);
 }
 
 /**
@@ -362,9 +316,7 @@ ephy_statusbar_set_popups_state (EphyStatusbar *statusbar,
 	}
 	else
 	{
-		gtk_tooltips_set_tip (statusbar->tooltips,
-				      priv->popups_manager_evbox,
-				      tooltip, NULL);
+		gtk_widget_set_tooltip_text (priv->popups_manager_icon, tooltip);
 
 		gtk_widget_show (priv->popups_manager_evbox);
 	}
@@ -472,21 +424,6 @@ ephy_statusbar_remove_widget (EphyStatusbar *statusbar,
 	gtk_container_remove (GTK_CONTAINER (priv->icon_container), widget);
 }
 
-
-/**
- * ephy_statusbar_get_tooltips:
- * @statusbar: an #EphyStatusbar
- *
- * Return value: the statusbar's #GtkTooltips object
- */
-GtkTooltips *
-ephy_statusbar_get_tooltips (EphyStatusbar *statusbar)
-{
-	g_return_val_if_fail (EPHY_IS_STATUSBAR (statusbar), NULL);
-
-	return statusbar->tooltips;
-}
-
 /**
  * ephy_statusbar_get_security_frame:
  * @statusbar: an #EphyStatusbar
